==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Η συσκευή είναι απασχολημένη</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>&apos;Ονομα</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>&apos;Αγνωστη</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Χρησιμοποιήθηκε από</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Αποστολή πιο πρόσφατου βίντεο</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Αποστολή ενός ή περισσότερων επιλεγμένων βίντεο</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Αποστολή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Παρακαλώ εγκαταστήστε πρόγραμμα video player</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Θα βρείτε το βίντεο ως επισύναψη</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Επιλογή ενός ή περισσότερων αρχείων</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Πλαίσιο</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Δείξε πάνω από την πλήρη οθόνη</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Δεξί κλικ για το μενού</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Ορισμός από το χρήστη</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Η συσκευή είναι απασχολημένη</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>&apos;Ονομα</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Χρησιμοποιήθηκε από</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>&apos;Αγνωστο</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation>διπλό κλικ για εξάπλωση στην άκρη</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Περιοχή</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Μεγένθυση</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>&apos;Ηχος</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Κωδικοποιητής</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Μην καταγράφεις τον κέρσορα</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Τοποθεσία αρχείου</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Αναπαραγωγή με</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Ελαχιστοποίηση όταν ξεκινήσει η εγγραφή</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Αρχή</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Στοπ</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Αποστολή</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Χρόνος εγγραφής</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Μέγεθος σε KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Μέγεθος περιοχής εγγραφής</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Φορμά</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ορισμός fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>&apos;Ανοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Αντίστροφη μέτρηση</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Παίξε τελευταίο βίντεο</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Αποστολή βίντεο</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Καρέ ανά δευτερόλεπτο</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Εκκίνηση</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Αρχική</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Υποστήριξη</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Προγραμματιστής</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Καρέ</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Δωρεά</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Μεταφράσεις</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Πηγαίος κώδικας</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Ορατό στις ειδοποιήσεις</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Νέα έκδοση διαθέσιμη</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Κωδικοποιητής βίντεο</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Κωδικοποιητή ήχου</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Κάμερα web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Επιλογή κάμερας web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Καθρεφτισμός</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>&apos;Ολες οι </translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Αρχική σελίδα προγραμματιστή</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Καταγραφέας</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Επιλογή καταγραφέα</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Η συσκευή είναι απασχολημένη</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>&apos;Ονομα</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>&apos;Αγνωστη</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Χρησιμοποιήθηκε από</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Αποστολή πιο πρόσφατου βίντεο</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Αποστολή ενός ή περισσότερων επιλεγμένων βίντεο</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Αποστολή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Παρακαλώ εγκαταστήστε πρόγραμμα video player</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Θα βρείτε το βίντεο ως επισύναψη</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Επιλογή ενός ή περισσότερων αρχείων</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Πλαίσιο</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Δείξε πάνω από την πλήρη οθόνη</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Δεξί κλικ για το μενού</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Ορισμός από το χρήστη</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Η συσκευή είναι απασχολημένη</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>&apos;Ονομα</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Χρησιμοποιήθηκε από</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>&apos;Αγνωστο</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Περιοχή</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Μεγένθυση</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>&apos;Ηχος</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Κωδικοποιητής</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Μην καταγράφεις τον κέρσορα</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Τοποθεσία αρχείου</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Αναπαραγωγή με</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Ελαχιστοποίηση όταν ξεκινήσει η εγγραφή</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Αρχή</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Στοπ</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Αποστολή</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Χρόνος εγγραφής</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Μέγεθος σε KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Μέγεθος περιοχής εγγραφής</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Φορμά</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ορισμός fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>&apos;Ανοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Αντίστροφη μέτρηση</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Παίξε τελευταίο βίντεο</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Αποστολή βίντεο</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Καρέ ανά δευτερόλεπτο</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Εκκίνηση</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Αρχική</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Υποστήριξη</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Προγραμματιστής</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Καρέ</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Δωρεά</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Μεταφράσεις</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Πηγαίος κώδικας</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Ορατό στις ειδοποιήσεις</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Νέα έκδοση διαθέσιμη</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Κωδικοποιητής βίντεο</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Κωδικοποιητή ήχου</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Κάμερα web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Επιλογή κάμερας web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Καθρεφτισμός</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>&apos;Ολες οι </translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Αρχική σελίδα προγραμματιστή</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Καταγραφέας</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Επιλογή καταγραφέα</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
